import difflib

useless_street_keywords = ["Phố", "Đường"]
useless_ward_keywords = ["Phường", "Quận", "Huyện"]


def get_all_streets(standard_data):
    all_streets = []
    for district in standard_data["district"]:
        for street in district["streets"]:
            street = remove_keywords(useless_street_keywords, street)
            all_streets.append(street)
    return all_streets


def get_all_wards(standard_data):
    all_wards = []
    for district in standard_data["district"]:
        for ward in district["wards"]:
            ward = remove_keywords(useless_ward_keywords, ward)
            all_wards.append(ward)
    return all_wards


def get_all_district(standard_data):
    all_districts = []
    for district in standard_data["district"]:
        all_districts.append(district["name"])
        
    return all_districts


def find_closest_match(input_street, standard_data):
    closest_match = difflib.get_close_matches(input_street, standard_data)
    if closest_match:
        return closest_match[0]

    return input_street


def standardize_street_name(street: str) -> str:
    street = remove_keywords(useless_street_keywords, street)
    all_streets = get_all_streets(data)
    ans = find_closest_match(street, all_streets)
    return ans


def standardize_ward_name(ward: str) -> str:
    ward = remove_keywords(useless_ward_keywords, ward)
    all_wards = get_all_wards(data)
    ans = find_closest_match(ward, all_wards)
    return ans


def standardize_district_name(district: str) -> str:
    all_districts = get_all_district(data)
    ans = find_closest_match(district, all_districts)
    return ans


def remove_keywords(useless_keywords: list, street: str) -> str:
    for keyword in useless_keywords:
        street = street.replace(keyword, "").strip()
    return street


data = {
    "district": [
        {
            "date": "2024-04-27 00:07:43",
            "name": "Gia Lâm",
            "wards": [
                    "Trâu quỳ",
                    "Bồ Đề",
                    "Ngọc Lâm",
                    "Trâu Quỳ",
                    "Yên Viên",
                    "Bát Tràng",
                    "Cổ Bi",
                    "Đa Tốn",
                    "Đặng Xá",
                    "Đình Xuyên",
                    "Đông Dư",
                    "Dương Hà",
                    "Dương Quang",
                    "Dương Xá",
                    "Kiêu Kỵ",
                    "Kim Lan",
                    "Kim Sơn",
                    "Lệ Chi",
                    "Ninh Hiệp",
                    "Phù Đổng",
                    "Phú Thị",
                    "Trung Màu",
                    "Văn Đức",
                    "Yên Thường",
                    "Yên Viên 2"
            ],
            "streets": [
                "Đường A Đào Nguyên",
                "Đường Cầu Đuống",
                "Đường Cầu Vượt Phú Thị",
                "Đường Chăn Nuôi",
                "Đường Cổ Bi",
                "Đường Cửu Việt 1",
                "Đường Cửu Việt 2",
                "Đa Tốn",
                "Đại Đồng",
                "Đường Đặng Phúc Thông",
                "Đường Đề Trụ",
                "Đường Đình Xuyên",
                "Đường Dương Hà - Đình Xuyên",
                "Đường K612",
                "Đường Dương Xá",
                "Giang Cao",
                "Đường Hà Huy Tập",
                "KCN Dương Xá",
                "Đường Kênh Dài",
                "Cả",
                "Đường Ngô Xuân Quảng",
                "Đường Nguyễn Bình",
                "Đường Nguyễn Đức Thuận",
                "Đường Nguyễn Đức Thuận",
                "Đường Nguyễn Huy Nhuận",
                "Đường Ninh Hiệp",
                "Đường Phan Đăng Lưu",
                "Đường Phong Xuân",
                "Đường QL 39",
                "Đường Quốc Lộ 1",
                "Đường Quốc Lộ 5",
                "Đường Trâu quỳ",
                "Đường Thiên Đức",
                "Đường Thôn Bát Tràng",
                "Đường Thôn Hàn Lạc",
                "Đường Thôn Tô Khê",
                "Đường Thôn Trân Tảo",
                "Đường Thú Y",
                "Đường Tỉnh Lộ 179",
                "Đường Tỉnh Lộ 181",
                "Đường Tỉnh lộ 195",
                "Đường Tỉnh Lộ 20",
                "Đường Tỉnh Lộ 270",
                "Đường Trâu Qùy",
                "Đường Trung Quan",
                "Đường Voi Phục",
                "Đường Xóm 1",
                "Đường Ỷ Lan",
                "Đường Yên Thường"
            ]
        },
        {
            "date": "2024-04-27 00:07:43",
            "name": "Hà Đông",
            "wards": [
                    "Ba La",
                    "Biên Giang",
                    "Đồng Mai",
                    "Dương Nội",
                    "Hà Cầu",
                    "Kiến Hưng",
                    "La Khê",
                    "Mộ Lao",
                    "Nguyễn Trãi",
                    "Phú La",
                    "Phú Lãm",
                    "Phú Lương",
                    "Phúc La",
                    "Phường Thượng Đình",
                    "Quang Trung",
                    "Quang Trung, Hà Đông",
                    "Thanh Lãm",
                    "Thanh Xuân",
                    "Thị trấn Xốm",
                    "Văn Khê 1",
                    "Văn Khê 2",
                    "Văn Mỗ",
                    "Vạn Phúc",
                    "Văn Quán",
                    "Xã Phú Cầu",
                    "Yên Nghĩa",
                    "Yết Kiêu"
            ],
            "streets": [
                "Đường Phan Đình Giót",
                "Đường An Hòa",
                "Đường Ao Sen",
                "Đường Ba La",
                "Đường Bà Triệu",
                "Bạch Đằng, Vạn Phúc",
                "Phố Bạch Thái Bưởi",
                "Đường Bế Văn Đàn",
                "Đường Bùi Bằng Đoàn",
                "Đường Cao Thắng",
                "Cầu Am",
                "Cầu Đơ 1",
                "Cầu Tuân",
                "Đường Chiến Thắng",
                "Đường Chu Văn An",
                "Đường Chung cư La Khê, nhà NC2",
                "Cổng Ngõ Bắc",
                "CT 7B",
                "Đa Sỹ",
                "Đường Đại An",
                "Phố Đinh Tiên Hoàng",
                "Đường Do Lộ",
                "Đường Động Lãm",
                "Đường Phú Lương",
                "Đường 19-5",
                "Đường Chiến Thắng",
                "Đường Chợ",
                "Đường Đất",
                "Đường làng Nhân Trạch",
                "Đường Thanh Lãm",
                "Đường Hà Trì",
                "Đường Hoàng Diệu",
                "Đường Hoàng Hạnh",
                "Đường Hoàng Hoa Thám",
                "Đường Hoàng Văn Thụ",
                "Đường Hữu hòa",
                "Đường Hữu Hưng",
                "Đường Huỳnh Thúc Kháng",
                "Đường Khối Độc Lập",
                "Đường Khu Đồng Dưa",
                "Đường Kiến Hưng",
                "Đường Làng La Dương",
                "Đường Làng Việt Kiều Châu Âu",
                "Đường Lê Hồng Phong",
                "Phố Lê Hữu Trác",
                "Đường Lê Lai",
                "Đường Lê Lợi",
                "Đường Lê Quý Đôn",
                "Đường Lê Trọng Tấn",
                "Lê Văn Lương kéo dài",
                "Liền kề 9",
                "Đường Lương Ngọc Quyến",
                "Đường Lương Văn Can",
                "Đường Lý Thường Kiệt",
                "Đường Lý Tự Trọng",
                "Man bồi gốc găng",
                "Đường Mậu Lương",
                "Đường Minh Khai",
                "Đường Mười Chín Tháng Năm",
                "Đường Ngô Gia Khảm",
                "Đường Ngô Gia Tự",
                "Đường Ngô Quyền",
                "Đường Ngô Thì Nhậm",
                "Đường Ngô Thì Sỹ",
                "Phố Nguyễn Công Trứ",
                "Đường Nguyễn Khuyến",
                "Đường Nguyễn Thái Học",
                "Đường Nguyễn Thượng Hiền",
                "Đường Nguyễn Trãi",
                "Đường Nguyễn Văn Lộc",
                "Phố Nguyễn Văn Trỗi",
                "Đường Nguyễn Văn Trỗi",
                "Đường Nguyễn Viết Xuân",
                "Đường Nhuệ Giang",
                "Đường Phan Bội Châu",
                "Đường Phan Chu Trinh",
                "Phố Phan Đình Giót",
                "Đường Phan Đình Giót",
                "Đường Phan Đình Phùng",
                "Đường Phan Huy Chú",
                "Phố Lụa",
                "Đường Phố Thanh Bình",
                "Phố Xốm",
                "Đường Phú Lãm",
                "Đường Phú Lương",
                "Đường Phùng Hưng",
                "Đường Phượng Bãi, Biên Giang",
                "Đường Quang Trung",
                "Quốc lộ 6",
                "Đường Quốc lộ 21B",
                "Đường Tản Đà",
                "Đường Tây Sơn",
                "Đường Thanh Bình",
                "Đường Thượng Mạo",
                "Đường Tiểu khu CN SimCo Sông Đà",
                "Đường Tỉnh lộ 70",
                "Đường Tỉnh lộ 70",
                "Phố Tô Hiến Thành",
                "Đường Tô Hiệu",
                "Phố Tô Hiệu",
                "Đường Tố Hữu",
                "Phố Tôn Hiến Thành",
                "Đường Trần Đăng Ninh",
                "Đường Trần Hưng Đạo",
                "Đường Trần Phú",
                "Đường Trần Văn Chuông",
                "Đường Trinh Lương",
                "Đường Trưng Nhị",
                "Đường Trưng Trắc",
                "Đường Trương Công Định",
                "TTTM",
                "Đường Văn Khê",
                "Đường Văn Phú",
                "Đường Vạn Phúc",
                "Đường Văn Quán",
                "Đường Văn Yên",
                "Đường Võ Thị Sáu",
                "Đường Yên Nghĩa",
                "Đường Yên Phúc",
                "Đường Yết Kiêu"
            ]
        },
        {
            "date": "2024-04-27 00:07:43",
            "name": "Hoàng Mai",
            "wards": [
                "Đại Kim",
                "Định Công",
                "Giải Phóng",
                "Giáp Bát",
                "Hoàng Liệt",
                "Hoàng Văn Thụ",
                "Lĩnh Nam",
                "Mai Động",
                "Pháp Vân",
                "Tân Mai",
                "Thanh Trì",
                "Thịnh Liệt",
                "Trần Phú",
                "Tương Mai",
                "Vĩnh Hưng",
                "Vĩnh Hưng 2",
                "Yên Sở"
            ],
            "streets": [
                "Phố An Xá",
                "Bắc Linh Đàm",
                "Đường Bằng A1",
                "Đường Bằng A2",
                "Đường Bằng A3",
                "Đường Bằng B",
                "Đường Bằng Liệt",
                "Đường Bờ Mương",
                "Phố Bùi Huy Bích",
                "Đường Cao tốc Pháp Vân",
                "Cầu Dậu",
                "Đường Cầu Thanh Trì",
                "CT 4B",
                "Đường Đại Đồng",
                "Đường Đại Từ",
                "Đường Đặng Xuân Bảng",
                "Đền Lừ",
                "Đường Định Công",
                "Định Công Hạ",
                "Đường Định Công Thượng",
                "Đường Đoàn Kết",
                "Đường Đông Thiên",
                "Đường Bắc Linh Đàm",
                "Đường Giải Phóng",
                "Đường giải phóng",
                "Đường Giải Phóng",
                "Đường Giáp Bát",
                "Đường Giáp Nhị",
                "Đường Hoàng Liệt",
                "Đường Hoàng Mai",
                "Phố Hưng Phúc",
                "Đường KĐT Định Công",
                "Đường KĐT Linh Đàm",
                "Phố Kim Đồng",
                "Đường Kim Giang",
                "Phố Kim Ngưu",
                "Đường Km 9 - Quốc Lộ 1A",
                "Phố Lê Trọng Tấn",
                "Đường Linh Đàm",
                "Đường Linh Đường",
                "Đường Lĩnh Nam",
                "Đường Lương Khánh Thiện",
                "Đường Mai Động",
                "Đường Mai Khai",
                "Phố Minh Khai",
                "Đường Nam Dư",
                "Đường Nghiêm Xuân Yêm",
                "Đường Ngõ 24/99 Kim Đồng",
                "Đường Ngõ 250/50, Kim Giang",
                "Đường Ngõ 364 Giải Phóng",
                "Đường Ngọc Hồi",
                "Đường Ngũ Nhạc",
                "Đường Nguyễn An Ninh",
                "Đường Nguyễn Cảnh Dị",
                "Đường Nguyễn Chính",
                "Đường Nguyễn Công Thái",
                "Đường Nguyễn Đức Cảnh",
                "Đường Nguyễn Duy Trinh",
                "Đường Nguyễn Hữu Thọ",
                "Đường Nguyễn Khoái",
                "Đường Nguyễn Khoái",
                "Đường Pháp Vân",
                "Phố Mới",
                "Đường QL1A",
                "Phố Sở Thượng",
                "Đường Tam Trinh",
                "Đường Tam Trinh",
                "Đường Tân Mai",
                "Đường Tây Trà",
                "Đường Thanh Đàm",
                "Đường Thanh Lân",
                "Đường Thịnh Liệt",
                "Đường Thúy Lĩnh",
                "Đường Trần Điền",
                "Đường Trần Điền",
                "Trần Nguyên Đán",
                "Đường Trần Thủ Độ",
                "Đường Trương Định",
                "Đường Trương Định",
                "Tương Mai",
                "Đường Tựu Liệt",
                "Đường Vĩnh Hưng",
                "Đường Vũ Tông Phan",
                "Đường Xóm 5",
                "Yên Duyên",
                "Đường Yên Sở"
            ]
        },
        {
            "name": "Cầu Giấy",
            "wards": [
                "Cầu Giấy",
                "Dịch Vọng",
                "Dịch Vọng Hậu",
                "Mai Dịch",
                "Mễ Trì",
                "Mỹ Đình",
                "Nam Trung Yên",
                "Nghĩa Đô",
                "Nghĩa Tân",
                "Nghĩa Đô",
                "Nhân Chính",
                "Phường Quan Hoa, Quận Cầu Giấy",
                "Quan Hoa",
                "Trung Hòa",
                "Trung Hòa Nhân Chính",
                "Từ Liêm",
                "Vĩnh Phúc",
                "Yên Hòa"
            ],
            "streets": [
                "Đường Bờ Sông",
                "Đường Cầu Giấy",
                "Đường Cầu vượt Mai Dịch",
                "Phố Chùa Hà",
                "Đường Cốm Vòng",
                "Đường Đặng Thùy Trâm",
                "Đường Dịch Vọng",
                "Đường Dịch Vọng Hậu",
                "Phố Doãn Kế Thiện",
                "Đường Đồng Bông",
                "Đường Đông Quan",
                "Đường 800A",
                "Đường B5",
                "Đường Bờ Sông",
                "Dương Đình Nghệ",
                "Đường Hoa Bằng",
                "Đường Hoàng Ngân",
                "Đường Phan Văn Trường",
                "Phố Dương Quảng Hàm",
                "Đường số 3",
                "Đường Trung Hòa",
                "Đường Duy Tân",
                "Đường Hồ Tùng Mậu",
                "Phố Hoa Bằng",
                "Phố Hoàng Đạo Thúy",
                "Phố Hoàng Minh Giám",
                "Phố Hoàng Ngân",
                "Đường Hoàng Quốc Việt",
                "Phố Hoàng Sâm",
                "Đường K800A",
                "Đường Khu ĐTM Cầu Giấy",
                "Đường Khu tập thể Bảo Việt",
                "Khu X1",
                "Đường Lạc Long Quân",
                "Đường Lê Đức Thọ Kéo Dài",
                "Đường Lê Văn Lương",
                "Đường Lê Văn Lương",
                "Lô 02 Nguyễn Khánh Toàn",
                "Đường Mạc Thái Tổ",
                "Phố Mai Dịch",
                "Đường Mễ Trì",
                "Phố Nghĩa Tân",
                "Đường Ngõ 72/38, Dương Quảng Hàm",
                "Nguyễn Chánh",
                "Đường Nguyễn Đình Hoàn",
                "Đường Nguyễn Khả Trạc",
                "Đường Nguyễn Khang",
                "Đường Nguyễn Khánh Toàn",
                "Phố Nguyễn Ngọc Vũ",
                "Đường Nguyễn Phong Sắc",
                "Phố Nguyễn Thị Định",
                "Nguyễn Thị Định",
                "Phố Nguyễn Thị Thập",
                "Đường Nguyễn Văn Huyên",
                "Nguyễn Văn Huyên kéo dài",
                "Đường Phạm Thận Duật",
                "Đường Phạm Thuận Duật",
                "Phố Phạm Tuấn Tài",
                "Phố Phan Văn Trường",
                "Phố Dịch Vọng",
                "Đường Phố Hoa Bằng",
                "Phố Phùng Chí Kiên",
                "Đường Quan Hoa",
                "Phố Quan Nhân",
                "Quan Nhân",
                "Đường Số 24, Đường Hoàng Quốc Việt, Tổ 46",
                "Đường Thành Thái",
                "Phố Tô Hiệu",
                "Tôn Thất Thuyết",
                "Phố Trần Bình",
                "Phố Trần Đăng Ninh",
                "Đường Trần Duy Hưng",
                "Phố Trần Kim Xuyến",
                "Phố Trần Quốc Hoàn",
                "Phố Trần Quý Kiên",
                "Đường Trần Thái Tông",
                "Phố Trần Tử Bình",
                "Đường Trần Vỹ",
                "Phố Trung Hòa",
                "Phố Trung Kính",
                "Đường Trung Yên 1",
                "Đường Trung Yên 10",
                "Đường Trung Yên 10A",
                "Đường Trung Yên 10B",
                "Đường Trung Yên 11",
                "Đường Trung Yên 11A",
                "Đường Trung Yên 11B",
                "Đường Trung Yên 12",
                "Đường Trung Yên 13",
                "Trung yên 14",
                "Đường Trung Yên 15A",
                "Đường Trung Yên 15B",
                "Đường Trung Yên 15C",
                "Đường Trung Yên 15D",
                "Đường Trung Yên 2",
                "Đường Trung Yên 3",
                "Đường Trung Yên 4",
                "Đường Trung Yên 5",
                "Đường Trung Yên 6",
                "Đường Trung Yên 7",
                "Đường Trung Yên 8",
                "Đường Trung Yên 9",
                "Đường Ven Sông",
                "Vũ Phạm Hàm",
                "Đường Xuân Thủy",
                "Đường Xuân Thủy, Phường Dịch Vọng Hậu",
                "Đường Yên Hòa"
            ]
        },
        {
            "date": "2024-04-27 00:07:44",
            "name": "Long Biên",
            "wards": [
                "Bồ Đề",
                "Cự Khối",
                "Đức Giang",
                "Gia Huy",
                "Gia Lâm",
                "Gia Thuỵ",
                "Giang Biên",
                "Long Biên",
                "Ngọc Lâm",
                "Ngọc Thuỵ",
                "Phúc Đồng",
                "Phúc Lợi",
                "Hoàng Liệt",
                "Nhật Tân",
                "Sài Đồng",
                "Thạch Bàn",
                "Thượng Thành",
                "Tư Đình",
                "Việt Hưng",
            ],
            "streets": [
                "Đường Anh Đào 2 Khu đô thị Vincom",
                "Đường Anh Đào 9 Khu đô thị Vincom",
                "Đường Hoa Phượng 4 Khu đô thị Vincom",
                "Đường Hoa Sữa 2 Khu đô thị Vincom",
                "Đường Ái Mộ",
                "Đường Anh Đào 1 Khu đô thị Vincom",
                "Đường Anh Đào 10 Khu đô thị Vincom",
                "Đường Anh Đào 11 Khu đô thị Vincom",
                "Đường Anh Đào 3 Khu đô thị Vincom",
                "Đường Anh Đào 4 Khu đô thị Vincom",
                "Đường Anh Đào 5 Khu đô thị Vincom",
                "Đường Anh Đào 6 Khu đô thị Vincom",
                "Đường Anh Đào 7 Khu đô thị Vincom",
                "Đường Anh Đào 8 Khu đô thị Vincom",
                "Đường Bắc Cầu",
                "Đường Bằng Lăng",
                "Phố Bồ Đề",
                "Đường Bồ Đề",
                "Đường Cầu Bây",
                "Đường Cổ Linh",
                "Đường Công Nghiệp 1",
                "Đường Công Nghiệp 2",
                "Đường Công Nghiệp 3",
                "Đường Công Nghiệp 4",
                "Đường Công Nghiệp 6",
                "Đường Công Nghiệp 8",
                "Đặng Vũ Hỷ",
                "Đường Đê Vàng",
                "Đường Đoàn Khuê",
                "Đường Đức Giang",
                "Đường Nguyễn Sơn",
                "Đường Phú yên",
                "Phố Gia Quất",
                "Đường Gia Thượng",
                "Phố Gia Thụy",
                "Giang Biên",
                "Đường Hoa Hồng Khu đô thị Vincom",
                "Đường Hoa Lâm",
                "Đường Hoa Lan 1 Khu đô thị Vincom",
                "Đường Hoa Lan 2 Khu đô thị Vincom",
                "Đường Hoa Lan 3 Khu đô thị Vincom",
                "Đường Hoa Lan 4 Khu đô thị Vincom",
                "Đường Hoa Lan 5 Khu đô thị Vincom",
                "Đường Hoa Lan 6 Khu đô thị Vincom",
                "Đường Hoa Lan 7 Khu đô thị Vincom",
                "Đường Hoa Lan 8 Khu đô thị Vincom",
                "Đường Hoa Lan Khu đô thị Vincom",
                "Đường Hoa Phượng",
                "Đường Hoa Phượng 1 Khu đô thị Vincom",
                "Đường Hoa Phượng 2 Khu đô thị Vincom",
                "Đường Hoa Phượng 3 Khu đô thị Vincom",
                "Đường Hoa Phượng 5 Khu đô thị Vincom",
                "Đường Hoa Phượng 6 Khu đô thị Vincom",
                "Đường Hoa Phượng 7 Khu đô thị Vincom",
                "Đường Hoa Phượng 8 Khu đô thị Vincom",
                "Đường Hoa Phượng Khu đô thị Vincom",
                "Hoa Sữa",
                "Đường Hoa Sữa 1 Khu đô thị Vincom",
                "Đường Hoa Sữa 10 Khu đô thị Vincom",
                "Đường Hoa Sữa 11 Khu đô thị Vincom",
                "Đường Hoa Sữa 3 Khu đô thị Vincom",
                "Đường Hoa Sữa 4 Khu đô thị Vincom",
                "Đường Hoa Sữa 5 Khu đô thị Vincom",
                "Đường Hoa Sữa 6 Khu đô thị Vincom",
                "Đường Hoa Sữa 7 Khu đô thị Vincom",
                "Đường Hoa Sữa 8 Khu đô thị Vincom",
                "Đường Hoa Sữa 9 Khu đô thị Vincom",
                "Hoàng Như Tiếp",
                "Đường Huỳnh Tấn Phát",
                "Đường Huỳnh Văn Nghệ",
                "Đường KĐT mới Sài Đồng",
                "Đường KĐT Việt Hưng P204-A2 CT20 Giang Biên",
                "Đường Kẻ Tạnh",
                "Đường Khu A1-A2-A3, Cự Khối",
                "Đường Khu đô thị garden City",
                "Đường Khu đô thị mới Vincom Long Biên",
                "Đường Kim Quan",
                "Đường Lâm Du",
                "Đường Lâm Hạ",
                "Phố Lệ Mật",
                "Đường Long Biên",
                "Đường Long Biên 1",
                "Đường Long Biên 2",
                "Đường Lưu Khánh Đàm",
                "Phố Mai Phúc",
                "Đường Ngõ 116 Ngọc Thụy",
                "Đường Ngô Gia Khảm",
                "Đường Ngô Gia Tự",
                "Đường Ngọc Lâm",
                "Đường Ngọc Thụy",
                "Đường Ngọc Trì",
                "Đường Nguyễn Cao Luyện",
                "Đường Nguyễn Đức Thuận",
                "Đường Nguyễn Sơn",
                "Đường Nguyễn Sơn",
                "Đường Nguyễn Văn Cừ",
                "Đường Nguyễn Văn Hưởng",
                "Đường Nguyễn Văn Linh",
                "Đường Ô Cách",
                "Đường Phan Văn Đảng",
                "Phố Trạm",
                "Phố Việt Hưng",
                "Đường Phú Viên",
                "Đường Quốc Lộ 1",
                "Đường Quốc lộ 5",
                "Phố Quốc Phương Trại",
                "Đường Sài Đồng",
                "Đường Tân Thụy",
                "Đường Thạch Bàn",
                "Đường Thạch Cầu",
                "Đường Thanh Am",
                "Đường Thép Mới",
                "Đường Tỉnh Lộ 20",
                "Tình Quang",
                "Trung Tâm thương mại VinCom Center Long Biên",
                "Đường Trường Lâm",
                "Đường Tư Đình",
                "Đường Vạn Hạnh",
                "Đường Việt Hưng",
                "Đường Vũ Xuân Thiều",
                "Phố Xuân Đỗ"
            ]
        },
        {
            "date": "2024-04-27 00:07:44",
            "name": "Thường Tín",
            "wards": [
                "Dũng Tiến",
                "Duyên Thái",
                "Hà Hồi",
                "Hiền Giang",
                "Hòa Bình",
                "Liên Phương",
                "Nghiêm Xuyên",
                "Nhị Khê",
                "Ninh Sở",
                "Quất Động",
                "Tân Minh",
                "Thị trấn Thường Tín",
                "Thư Phú",
                "Tô Hiệu",
                "Vạn Điểm",
                "Văn Phú",
                "Văn Tự"
            ],
            "streets": [
                "AH 1",
                "Đường Cống Xuyên",
                "Đường Dũng Tiến",
                "Đường 71",
                "Đường Bộ Đầu-Vạn Điểm",
                "Đường KCN Quất Động",
                "Liên Phương",
                "Đường Liên Xá",
                "Đường Nghiêm Xá",
                "Đường Nghiêm Xuyên",
                "Phố Ga",
                "Quốc Lộ 1",
                "Đường Quốc Lộ 1",
                "Quốc lộ 1A",
                "Đường Quốc Lộ 1A, Phố Ga",
                "Đường Quốc lộ 71",
                "Tỉnh lộ 427",
                "Đường Tỉnh lộ 71",
                "Đường Tỉnh lộ 73",
                "Đường Trần Phú"
            ]
        },
        {
            "date": "2024-04-27 00:07:45",
            "name": "Bắc Từ Liêm",
            "wards": [
                "Cổ Nhuế",
                "Đông Ngạc",
                "Đức Thắng",
                "Liên Mạc",
                "Minh Khai",
                "Phú Diễn",
                "Phúc Diễn",
                "Tây Tựu",
                "Thượng Cát",
                "Thụy Phương",
                "Xuân Đỉnh",
                "Xuân Tảo"
            ],
            "streets": [
                "Đường Cầu Thăng Long",
                "Đường CN 2",
                "Đường CN 4",
                "Đường CN 5",
                "Đường CN 6",
                "Đường CN 7",
                "Đường CN 8",
                "Đường CN 9",
                "Đường Cổ Nhuế",
                "Cụm công nghiệp vừa và nhỏ Từ Liêm",
                "Đường Đại Cát",
                "Đường Đông Ngạc",
                "Đường Đường 69",
                "Đường Cầu Diễn",
                "Đường CN4",
                "Đường không tên",
                "Đường Đường Phú Diễn",
                "Đường Hoàng Quốc Việt",
                "Đường Hoàng Xá",
                "Đường Lê Văn Hiến",
                "Đường Liên Cơ",
                "Đường Liên Mạc",
                "Đường Liên Xã",
                "Đường Lũng Lô A",
                "Đường Ngõ 46 Hoàng Liên",
                "Đường Ngọa Long",
                "Nguyên Xá",
                "Đường Nông Lâm",
                "Đường Phạm Tuấn Tài",
                "Đường Phạm Văn Đồng",
                "Đường Phan Bá Vành",
                "Phố Nhổn",
                "Đường Phố Viên",
                "Đường Phú Diễn",
                "Đường Phú Kiều",
                "Đường Phúc Lý",
                "Phố Tân Phong",
                "Đường Tân Xuân",
                "Đường Tăng Thiết Giáp",
                "Đường Thượng Cát",
                "Đường Thụy Phương",
                "Đường Tổ dân phố Phúc Lý",
                "Đường Trần Cung",
                "Đường Văn Trì",
                "Đường Xuân Đỉnh",
                "Đường Yên Nội"
            ]
        },
        {
            "date": "2024-04-27 00:07:45",
            "name": "Hai Bà Trưng",
            "wards": [
                "Bạch Đằng",
                "Bách Khoa",
                "Bạch Mai",
                "Bùi Thị Xuân",
                "Cầu Dền",
                "Cửa Nam",
                "Đại Cồ Việt",
                "Đống Mác",
                "Đồng Nhân",
                "Đồng Tâm",
                "Đồng Xuân",
                "Hàm Long",
                "Hàng Bài",
                "Hồ Xuân Hương",
                "Hòa Mã",
                "Lê Đại Hành",
                "Lê Duẩn",
                "Lò Đúc",
                "Mai Động",
                "Mai Hắc Đế",
                "Minh Khai",

                "Ngô Thì Nhậm",
                "Nguyễn Du",
                "Nguyễn Bỉnh Khiêm",
                "Nguyễn Công Trứ",
                "Phạm Đình Hổ",
                "Phố Huế",
                "Phường Nguyễn Du",
                "Phường Trương Định",
                "Quỳnh Lôi",
                "Quỳnh Mai",
                "Thái Phiên",
                "Thanh Lương",
                "Thanh Nhàn",
                "Trần Hưng Đạo",
                "Tràng An",
                "Triệu Việt Vương",
                "Trương Định",
                "Tuệ Tĩnh",
                "Vĩnh Tuy"
            ],
            "streets": [
                "Đường Đại La",
                "Phố Bà Triệu",
                "Bà Triệu",
                "Đường Bạch Đằng",
                "Phố Bạch Mai",
                "Phố Bùi Ngọc Dương",
                "Phố Bùi Thị Xuân",
                "Phố Cảm Hội",
                "Đường Cao Đạt",
                "Đường Cầu Lạc Trung",
                "Đường Cầu Vĩnh Tuy",
                "Phố Chùa Vua",
                "Đường Dã Tượng",
                "Đường Đại Cồ Việt",
                "Phố Đại La",
                "Đường Đầm Trấu",
                "Đường Đê Trần Khát Chân",
                "Phố Đỗ Hành",
                "Phố Đỗ Ngọc Du",
                "Phố Đoàn Trần Nghiệp",
                "Đường Đội Cung",
                "Phố Đông Mác",
                "Phố Đồng Nhân",
                "Đường Bà Triệu",
                "Đường Bùi Thị Xuân",
                "Đường Lê Thanh Nghị",
                "Đường Tuệ Tĩnh",
                "Đường Yec Xanh",
                "Đường Giải Phóng",
                "Phố Hàm Long",
                "Phố Hàn Thuyên",
                "Phố Hàng Bài",
                "Phố Hàng Chuối",
                "Phố Hồ Xuân Hương",
                "Phố Hoa Lư",
                "Phố Hòa Mã",
                "Phố Hồng Mai",
                "Phố Hương Viên",
                "Khu tập thể Bách Khoa",
                "Khu tập thể Đại học Kinh tế Quốc dân",
                "Phố Kim Ngưu",
                "Phố Lạc Trung",
                "Đường Lãng Yên",
                "Phố Lê Đại Hành",
                "Đường Lê Duẩn",
                "Đường Lê Duẩn",
                "Phố Lê Gia Định",
                "Phố Lê Ngọc Hân",
                "Phố Lê Quý Đôn",
                "Phố Lê Thanh Nghị",
                "Phố Lê Văn Hưu",
                "Lĩnh Nam",
                "Phố Lò Đúc",
                "Phố Lương Yên",
                "Phố Mạc Thị Bưởi",
                "Phố Mai Hắc Đế",
                "Phố Minh Khai",
                "Đường Ngõ 254 Minh Khai",
                "Phố Ngô Thì Nhậm",
                "Ngô Văn Sở",
                "Nguyễn An Ninh",
                "Phố Nguyễn Bỉnh Khiêm",
                "Phố Nguyễn Cao",
                "Phố Nguyễn Công Trứ",
                "Phố Nguyễn Đình Chiểu",
                "Phố Nguyễn Du",
                "Nguyễn Hiền",
                "Phố Nguyễn Huy Tự",
                "Đường Nguyễn Khoái",
                "Phố Nguyễn Quyền",
                "Phố Nguyễn Thượng Hiền",
                "Phố Phạm Đình Hổ",
                "Phố Phan Chu Trinh",
                "Phố 8-3",
                "Phố Huế",
                "Đường Phố Trần Cao Vân",
                "Phố Vọng",
                "Phố Phù Đổng Thiên Vương",
                "Phố Phùng Khắc Khoan",
                "Đường Quỳnh Lôi",
                "Phố Quỳnh Mai",
                "Số 1 Trần Thánh Tông",
                "Phố Tạ Quang Bửu",
                "Đường Tám tháng ba",
                "Đường Tam Trinh",
                "Đường Tân Lạc",
                "Phố Tăng Bạt Hổ",
                "Đường Tây Kết",
                "Phố Thái Phiên",
                "Phố Thanh Nhàn",
                "Phố Thể Giao",
                "Phố Thi Sách",
                "Phố Thiền Quang",
                "Phố Thịnh Yên",
                "Đường Thọ Lão",
                "Phố Tô Hiến Thành",
                "Phố Trần Bình Trọng",
                "Phố Trần Cao Vân",
                "Phố Trần Đại Nghĩa",
                "Phố Trần Hưng Đạo",
                "Đường Trần Khánh Dư",
                "Đường Trần Khát Chân",
                "Phố Trần Nhân Tông",
                "Trần Quốc Toản",
                "Phố Trần Thánh Tông",
                "Phố Trần Xuân Soạn",
                "Phố Triệu Việt Vương",
                "Đường Trương Định",
                "Phố Tuệ Tĩnh",
                "Phố Vân Đồn",
                "Đường Vân Hồ I",
                "Đường Vân Hồ III",
                "Đường Vạn Kiếp",
                "Đường Vĩnh Tuy",
                "Phố Võ Thị Sáu",
                "Phố Vũ Hữu Lợi",
                "Phố Y.E.C Xanh",
                "Phố Yên Bái 1",
                "Phố Yên Bái 2",
                "Phố Yên Lạc",
                "Phố Yết Kiêu"
            ]
        },
        {
            "date": "2024-04-27 00:07:45",
            "name": "Mỹ Đức",
            "wards": [],
            "streets": [
                "Đường Cầu Ái Nàng",
                "Đường Đại Nghĩa",
                "Đường 74",
                "Đường Bờ Sông",
                "Đường Nghĩa Ái",
                "Phố Tế Tiêu",
                "Đường Tế Tiêu-Hương Sơn",
                "Đường Thành Thái",
                "Đường Tỉnh lộ 419",
                "Đường Tỉnh lộ 424",
                "Phố Văn Giang"
            ]
        },
        {
            "date": "2024-04-27 00:07:45",
            "name": "Sơn Tây",
            "wards": [
                "Cổ Đông",
                "Đường Lâm",
                "Lê Lợi",
                "Ngô Quyền",
                "Phú Thịnh",
                "Quang Trung",
                "Sơn Đông",
                "Sơn Lộc",
                "Trung Hưng",
                "Trung Sơn Trầm",
                "Viên Sơn"
            ],
            "streets": [
                "Đường Bình Sơn",
                "Đường Bốt Cũ",
                "Đường Cao Sơn",
                "Đường Cầu Trì",
                "Phố Chùa Thông",
                "Đường Chùa Thông, Sơn Lộc",
                "Cổ Đông",
                "Đường Đại Hà",
                "Đường Đại Quang",
                "Đường Đinh Tiên Hoàng",
                "Đường Đốc Ngữ",
                "Đường Đồi Chè",
                "Đường Đồi Chợ",
                "Đường Đồi Tầm",
                "Đường Đồi Vua",
                "Đường Đông A",
                "Đường Đồng Giếng",
                "Đường Đồng Mô",
                "Đường Đường Lâm",
                "Đường Thôn Bống",
                "Đường Gò La",
                "Đường Hoàng Diệu",
                "Đường Lê Lợi",
                "Đường Mai Trai",
                "Đường Nguyễn Thái Học",
                "Đường Phạm Ngũ Lão",
                "Phố Phó Đức Chính",
                "Phố Hàng",
                "Đường Phố Hàng",
                "Phố Ngô Quyền",
                "Đường Phú Nhi",
                "Phố Phù Xa",
                "Đường Phùng Khắc Khoan",
                "Đường Quang Trung",
                "Đường Quốc lộ 21",
                "Đường Sơn Lộc",
                "Đường Tân Phú",
                "Phố Thiên Mã",
                "Phố Thiều Xuân",
                "Phố Trạnh Trình",
                "Đường Trưng Vương",
                "Đường Tùng Thiện",
                "Đường Vạn An"
            ]
        },
        {
            "date": "2024-04-27 00:07:46",
            "name": "Đông Anh",
            "wards": [
                "Cổ Dương -Tiên Dương",
                "Thị Trấn Bần Yên Nhân",
                "Thị trấn Đông Anh",
                "Xã Bắc Hồng",
                "Xã Cổ Loa",
                "Xã Đại Mạch",
                "Xã Đông Hội",
                "Xã Dục Tú",
                "Xã Hải Bối",
                "Xã Kim Chung",
                "Xã Kim Nỗ",
                "Xã Liên Hà",
                "Xã Mai Lâm",
                "Xã Nam Hồng",
                "Xã Nguyên Khê",
                "Xã Tàm Xá",
                "Xã Thụy Lâm",
                "Xã Tiên Dương",
                "Xã Uy Nỗ",
                "Xã Vân Hà",
                "Xã Vân Nội",
                "Xã Việt Hùng",
                "Xã Vĩnh Ngọc",
                "Xã Võng La",
                "Xã Xuân Canh",
                "Xã Xuân Nội"
            ],
            "streets": [
                "Đường Xã Kim Chung",
                "Đường Bắc Hà",
                "Đường Bắc Thăng Long-Hải Bối",
                "Đường Bắc Thăng Long-Nội Bài",
                "Đường Bờ Hồ",
                "Đường Cao Lỗ",
                "Đường Cầu Đôi",
                "Đường Cầu Lớn-Nam Hồng",
                "Đường Cổ Loa",
                "Đường Cổ Vân",
                "Đường Đa Lộc",
                "Đường Đại Mạch",
                "Đường Đàn Dị",
                "Đường Đào Cam Mộc",
                "Đường Đào Duy Tùng",
                "Đông Anh",
                "Đường Đồng Dầu",
                "Đường Đông Hội",
                "Đường Đồng Quan",
                "Đường Đông Trù",
                "Đường Dục Nội",
                "Đường Dục Tú",
                "Đường Cụt",
                "Đường Đường số 23B",
                "Đường Xóm Trại",
                "Đường Ga Đông Anh",
                "Đường Hà Phong",
                "Đường Hội Phụ",
                "Phố Kênh Giữa",
                "Đường Lại Đà",
                "Đường Lâm Tiên",
                "Đường Lê Hữu Tựu",
                "Đường Liên Hà",
                "Đường Liên Xã",
                "Lương Nỗ",
                "Đường Mai Hiên",
                "Đường Nghĩa Vũ",
                "Đường Phố Chợ Nguyên Khê",
                "Phố Tó",
                "Đường Phương Trạch",
                "Đường Quốc lộ 23",
                "Đường Quốc lộ 23B",
                "Đường Quốc Lộ 3",
                "Đường Quốc Lộ 5",
                "Đường Thôn Đìa-Nam Hồng",
                "Đường Thụy Lâm",
                "Đường Tiên Hội",
                "Đường Tổ 54",
                "Đường Uy Mỗ",
                "Uy Nỗ",
                "Đường Vân Hà",
                "Đường Vân Trì",
                "Đường Võ Nguyên Giáp",
                "Đường Võ Nguyên Giáp",
                "Đường Xóm Đông",
                "Đường Xuân Canh"
            ]
        },
        {
            "date": "2024-04-27 00:07:46",
            "name": "Đan Phượng",
            "wards": [
                "Hạ Mỗ",
                "Hồng Hà",
                "Liên Hà",
                "Liên Hồng",
                "Tân Hội",
                "Tân Lập",
                "Thị trấn Phùng",
                "Thọ An",
                "Thọ Xuân",
                "Thượng Mỗ"
            ],
            "streets": [
                "Đường Đại Phùng",
                "Đường Đoài Khê",
                "Đường Đông Khê",
                "Đường Hạ Mỗ",
                "Đường Hạ Mỗ-Tân Hội",
                "Đường Liên Hà",
                "Đường Liên Hồng",
                "Nguyễn Thái Học",
                "Đường Phan Đình Phùng",
                "Đường Phượng Trì",
                "Đường Quốc lộ 32",
                "Đường Tân Hội",
                "Tây Sơn",
                "Đường Thượng Mỗ",
                "Đường Tình Yêu",
                "Đường Trung Thọ Dương"
            ]
        },
        {
            "date": "2024-04-27 00:07:46",
            "name": "Thanh Oai",
            "wards": [
                "Bình Minh",
                "Cao Viên",
                "Cự Khê",
                "Hồng Dương",
                "Tam Hưng",
                "Thanh Mai",
                "Thanh Thùy",
                "Thanh Văn",
                "Thị trấn Kim Bài",
                "TT Kim Bài"
            ],
            "streets": []
        },
        {
            "date": "2024-04-27 00:07:46",
            "name": "Đống Đa",
            "wards": [
                "Bách Khoa",
                "Cát Linh",
                "Cửa Nam",
                "Điện Biên",
                "Đống Đa",
                "Đồng Tâm",
                "Hàng Bột",
                "Khâm Thiên",
                "Khương Mai",
                "Khương Thượng",
                "Khương Trung",
                "Kim Liên",
                "Láng Hạ",
                "Láng Thượng",
                "Nam Đồng",
                "Ngã Tư Sở",
                "Ô Chợ Dừa",
                "Phường Kim Mã",
                "Phương Liên",
                "Phương Liệt",
                "Phương Mai",
                "Phường Văn",
                "Quang Trung",
                "Quốc Tử Giám",
                "Thái Hà",
                "Thành Công",
                "Thịnh Quang",
                "Thổ Quan",
                "Trung Liệt",
                "Trung Phụng",
                "Trung Tự",
                "Văn Chương",
                "Văn Miếu",
                "Vũ Thạnh"
            ],
            "streets": [
                "Đường Mai Anh Tuấn",
                "Quốc Tử Giám, Văn Miếu",
                "Đường Trần Hữu Tước",
                "Đường 62, Nguyễn Chí Thanh",
                "Phố Bích Câu",
                "Phố Cát Linh",
                "Phố Cầu Mới",
                "Phố Chùa Bộc",
                "Phố Chùa Láng",
                "Đường Chùa Nền",
                "Phố Đại La",
                "Phố Đặng Tiến Đông",
                "Phố Đặng Trần Côn",
                "Phố Đặng Văn Ngữ",
                "Đường Đào Duy Anh",
                "Đường Đê La Thành",
                "Đình Tương Thuận",
                "Phố Đoàn Thị Điểm",
                "Phố Đông Các",
                "Phố Đông Tác",
                "Đường Đặng Tiến Đông",
                "Đường Đường Láng",
                "Đường Đường Nguyễn Chí Thanh",
                "Đường Nguyễn Lương Bằng",
                "Đường Thái Thịnh",
                "Giảng Võ",
                "Phố Hàng Cháo",
                "Phố Hào Nam",
                "Hồ Ba Mẫu",
                "Phố Hồ Đắc Di",
                "Phố Hồ Giám",
                "Đường Hồ Văn Chương",
                "Phố Hoàng Cầu",
                "Phố Hoàng Ngọc Phách",
                "Phố Hoàng Tích Trí",
                "Phố Khâm Thiên",
                "Khu tập thể Kim Liên",
                "Khu tập thể Nam Đồng",
                "Khu tập thể Phương Mai",
                "Khu tập thể Trung Tự",
                "Phố Khương Thượng",
                "Phố Kim Hoa",
                "Đường Kim Liên Mới",
                "Đường La Thành",
                "Đường Láng",
                "Phố Láng Hạ",
                "Đường Lê Duẩn",
                "Lê Duẩn",
                "Phố Lê Trực",
                "Phố Lương Định Của",
                "Đường Lý Văn Phúc",
                "Phố Mai Anh Tuấn",
                "Nam Đồng",
                "Đường Nam Thành Công",
                "Ngách 27 Ngõ 4",
                "Ngách 39/178 Thái Hà",
                "Ngách 91/1 Lương Định Của",
                "Đường Ngõ 317 Tây sơn",
                "Đường Ngõ 49 Huỳnh Thúc Kháng",
                "Đường Ngõ 98 Thái Hà",
                "Phố Ngô Sĩ Liên",
                "Ngô Sỹ Liên",
                "Phố Ngô Tất Tố",
                "Đường Nguyễn Chí Thanh",
                "Nguyên Hồng",
                "Phố Nguyễn Khuyến",
                "Phố Nguyễn Lương Bằng",
                "Phố Nguyễn Như Đổ",
                "Phố Nguyễn Phúc Lai",
                "Phố Nguyễn Thái Học",
                "Nguyễn trãi",
                "Phố Phạm Ngọc Thạch",
                "Phố Phan Phù Tiên",
                "Phố Phan Văn Trị",
                "Phố Pháo Đài Láng",
                "Đường Phố 224",
                "Đường Phố Hoàng Cầu mới",
                "Phố Tây Sơn",
                "Phố Thái Thịnh",
                "Phố Phương Mai",
                "Quang Trung",
                "Phố Quốc Tử Giám",
                "Phố Tây Sơn",
                "Phố Thái Hà",
                "Đường Thái Hà Mới",
                "Phố Thái Thịnh",
                "Đường Thanh Miến",
                "Đường Thịnh Hào",
                "Đường Thịnh Quang",
                "Phố Tôn Đức Thắng",
                "Phố Tôn Thất Tùng",
                "Phố Trần Hữu Tước",
                "Phố Trần Quang Diệu",
                "Đường Trần Quí Cáp",
                "Phố Trần Quý Cáp",
                "Phố Trịnh Hoài Đức",
                "Phố Trúc Khê",
                "Phố Trung Liệt",
                "Đường Trường Chinh",
                "Trường Trinh",
                "Đường Văn Hương",
                "Phố Văn Miếu",
                "Đường Vĩnh Hồ",
                "Đường Võ Văn Dũng",
                "Phố Vũ Ngọc Phan",
                "Phố Vũ Thạnh",
                "Phố Xã Đàn",
                "Xã Đàn 2",
                "Phố Y Miếu",
                "Đường Yên Lãng"
            ]
        },
        {
            "date": "2024-04-27 00:07:47",
            "name": "Chương Mỹ",
            "wards": [],
            "streets": [
                "Đường Cấn Hữu",
                "Đường Chi Nê-Tinh Mỹ",
                "Đường Đìa Chiến Lược",
                "Đường Đồng Lệ",
                "Đường Mới Yên Cốc",
                "Đường N5 KCN Phú Nghĩa",
                "Đường T3 KCN Phú Nghĩa",
                "Đường Thanh Niên KCN Phú Nghĩa",
                "Đường Tương Lai",
                "Đường Hạ Dục",
                "Đường Hạnh Phúc",
                "Đường Hòa Sơn",
                "Đường Hợp Nhất",
                "Đường Khu Tân Bình",
                "Đường Km 28 +600",
                "Km 6",
                "Ngọc Hòa",
                "Đường Quốc lộ 21",
                "Đường Quốc lộ 6",
                "Tân Xuân",
                "Đường Thôn Đồi Hai",
                "Đường Tỉnh lộ 419",
                "Đường Trung Hòa-Trường Yên",
                "Đường Viết Tuấn",
                "Đường Yên Sơn"
            ]
        },
        {
            "date": "2024-04-27 00:07:47",
            "name": "Hoàn Kiếm",
            "wards": [
                "Chương Dương",
                "Chương Dương Độ",
                "Cửa Đông",
                "Cửa Nam",
                "Đồng Xuân",
                "Hai Bà Trưng",
                "Hàng Bạc",
                "Hàng Bài",
                "Hàng Bồ",
                "Hàng Bông",
                "Hàng Buồm",
                "Hàng Đào",
                "Hàng Gai",
                "Hàng Mã",
                "Hàng Trống",
                "Hoàn Kiếm",
                "Lê Đại Hành",
                "Lý Thái Tổ",
                "Ngọc Khánh",
                "Nguyễn Du",
                "Nguyễn Trung Trực",
                "Phạm Đình Hồ",
                "Phan Chu Trinh",
                "Phúc Tân",
                "Phường Phạm Đình Hổ",
                "Phường Thanh Sơn",
                "Trần Hưng Đạo",
                "Tràng Thi",
                "Tràng Tiền"
            ],
            "streets": [
                "44A",
                "Phố An Xá",
                "Phố Ấu Triệu",
                "Phố Bà Triệu",
                "Đường Bạch Đằng",
                "Đường Bạch Đằng",
                "Phố Bảo Khánh",
                "Đường Bảo Linh",
                "Phố Bát Đàn",
                "Phố Bát Sứ",
                "Bùi Thị Xuân",
                "Đường Cấm Chỉ",
                "Phố Cao Thắng",
                "Đường Cầu Chương Dương",
                "Đường Cầu Đất",
                "Phố Cầu Đông",
                "Phố Cầu Gỗ",
                "Đường Cầu Long Biên",
                "Đường Cầu Thê Húc",
                "Phố Chả Cá",
                "Phố Chân Cầm",
                "Đường Chiến Thắng",
                "Phố Chợ Gạo",
                "Đường Chương Dương",
                "Đường Chương Dương Độ",
                "Đường Cổ Tân",
                "Đường Cổng Đục",
                "Phố Cửa Đông",
                "Phố Cửa Nam",
                "Phố Dã Tượng",
                "Phố Đặng Thái Thân",
                "Phố Đào Duy Từ",
                "Đường Điện Biên Phủ",
                "Đường Đinh Công Tráng",
                "Phố Đinh Lễ",
                "Phố Đinh Liệt",
                "Phố Đình Ngang",
                "Phố Đinh Tiên Hoàng",
                "Dốc Bác Cổ",
                "Đường Đông Đản",
                "Đường Đông Thái",
                "Phố Đồng Xuân",
                "Đường Bà Triệu",
                "Đường Bát Đàn",
                "Đường Cửa Nam",
                "Đường Đình Lễ",
                "Đường Hàn Thuyên",
                "Đường Nam Ngư",
                "Đường Nguyễn Khiết",
                "Đường Đường Nguyễn Thái Học",
                "Đường Nguyễn Tư Giản",
                "Đường Phan Bội Châu",
                "Phố Đường Thành",
                "ĐườngTrần Quang Khải",
                "Phố Gầm Cầu",
                "Phố Gia Ngư",
                "Đường Hạ Hồi",
                "Phố Hà Trung",
                "Phố Hai Bà Trưng",
                "Phố Hàm Long",
                "Đường Hàm Tử Quan",
                "Phố Hàng Bạc",
                "Phố Hàng Bài",
                "Phố Hàng Bè",
                "Phố Hàng Bồ",
                "Phố Hàng Bông",
                "Phố Hàng Buồm",
                "Phố Hàng Bút",
                "Phố Hàng Cá",
                "Phố Hàng Cân",
                "Phố Hàng Chai",
                "Phố Hàng Chiếu",
                "Phố Hàng Chĩnh",
                "Đường Hàng Chĩnh",
                "Hàng Chuối",
                "Phố Hàng Cót",
                "Phố Hàng Da",
                "Phố Hàng Đào",
                "Phố Hàng Dầu",
                "Phố Hàng Đậu",
                "Phố Hàng Điếu",
                "Phố Hàng Đồng",
                "Phố Hàng Đường",
                "Phố Hàng Gà",
                "Phố Hàng Gai",
                "Phố Hàng Giấy",
                "Phố Hàng Giầy",
                "Phố Hàng Hòm",
                "Phố Hàng Khay",
                "Phố Hàng Khoai",
                "Phố Hàng Lược",
                "Phố Hàng Mã",
                "Phố Hàng Mắm",
                "Phố Hàng Mành",
                "Phố Hàng Muối",
                "Phố Hàng Ngang",
                "Phố Hàng Nón",
                "Phố Hàng Phèn",
                "Phố Hàng Quạt",
                "Phố Hàng Rươi",
                "Đường Hàng Than",
                "Phố Hàng Thiếc",
                "Phố Hàng Thùng",
                "Phố Hàng Tre",
                "Hàng Tre, phường Lý Thái Tổ",
                "Phố Hàng Trống",
                "Phố Hàng Vải",
                "Phố Hàng Vôi",
                "Phố Hồ Hoàn Kiếm",
                "Đường Hồng Hà",
                "Đường Hồng Hà",
                "Phố Hồng Phúc",
                "Kim Mã",
                "Phố Lãn Ông",
                "Đường Lê Duẩn",
                "Phố Lê Lai",
                "Phố Lê Phụng Hiểu",
                "Phố Lê Thạch",
                "Phố Lê Thái Tổ",
                "Phố Lê Thánh Tông",
                "Phố Lê Văn Hưu",
                "Phố Lê Văn Linh",
                "Phố Liên Trì",
                "Phố Lò Rèn",
                "Phố Lò Sũ",
                "Phố Lương Ngọc Quyến",
                "Phố Lương Văn Can",
                "Phố Lý Đạo Thành",
                "Phố Lý Nam Đế",
                "Phố Lý Quốc Sư",
                "Phố Lý Thái Tổ",
                "Phố Lý Thường Kiệt",
                "Phố Mã Mây",
                "Phố Nam Ngư",
                "Đường Ngõ 149 Lê Duẩn",
                "Đường Ngõ 435 Hồng Hà",
                "Phố Ngõ Gạch",
                "Ngô Quền",
                "Phố Ngô Quyền",
                "Phố Ngô Thì Nhậm",
                "Phố Ngõ Trạm",
                "Phố Ngô Văn Sở",
                "Đường Nguyễn Chế Nghĩa",
                "Phố Nguyễn Du",
                "Phố Nguyễn Gia Thiều",
                "Phố Nguyễn Hữu Huân",
                "Phố Nguyễn Khắc Cần",
                "Đường Nguyên Khiết",
                "Phố Nguyễn Quang Bích",
                "Phố Nguyễn Siêu",
                "Phố Nguyễn Thái Học",
                "Phố Nguyễn Thiện Thuật",
                "Phố Nguyễn Thiệp",
                "Đường Nguyễn Tử Giàn",
                "Phố Nguyễn Văn Tố",
                "Phố Nguyễn Xí",
                "Phố Nhà Chung",
                "Phố Nhà Hỏa",
                "Phố Nhà Thờ",
                "Phố Ô Quan Chưởng",
                "Phố Phạm Ngũ Lão",
                "Phố Phạm Sư Mạnh",
                "Phố Phan Bội Châu",
                "Phố Phan Chu Trinh",
                "Phố Phan Huy Chú",
                "Đường Phố 19-12",
                "Đường Phố Cầu Gỗ",
                "Phố Huế",
                "Phố Thuốc Bắc",
                "Phố Phủ Doãn",
                "Đường Phúc Tân",
                "Phố Phùng Hưng",
                "Phố Phùng Hưng Trong",
                "Phố Quán Sứ",
                "Phố Quang Trung",
                "Phố Tạ Hiện",
                "Phố Thanh Hà",
                "Đường Thanh Yên",
                "Thợ Nhộm",
                "Phố Thợ Nhuộm",
                "Phố Thuốc Bắc",
                "Đường Tô Hiến Thành",
                "Phố Tố Tịch",
                "Phố Tông Đản",
                "Đường Tống Duy Tân",
                "Phố Trần Bình Trọng",
                "Đường Trần Hưng Đạo",
                "Đường Trần Khánh Dư",
                "Phố Trần Nguyên Hãn",
                "Đường Trần Nhật Duật",
                "Đường Trần Quang Khải",
                "Phố Trần Quốc Toản",
                "Phố Tràng Thi",
                "Phố Tràng Tiền",
                "Tràng Tiền Plaza",
                "Phố Triệu Quốc Đạt",
                "Trung tâm Tràng Tiền",
                "Phố Trương Hán Siêu",
                "Đường Vạn Kiếp",
                "Đường Võ Văn Dũng",
                "Đường Vọng",
                "Đường Vọng Đức",
                "Đường Vọng Hà",
                "Đường Yên Thái",
                "Phố Yết Kiêu"
            ]
        },
        {
            "date": "2024-04-27 00:07:47",
            "name": "Hoài Đức",
            "wards": [
                "Thị trấn Trạm Trôi",
                "An Khánh",
                "Đắc Sở",
                "Di Trạch",
                "Đông La",
                "Đức Thượng",
                "Dương Liễu",
                "Kim Chung",
                "Lai Xá",
                "Lai Yên",
                "Sơn Đồng",
                "Song Phương",
                "Thị trấn Trạm Trôi",
                "Vân Canh",
                "Vân Côn",
                "Yên Sở"
            ],
            "streets": [
                "Phố Cảo Bắc",
                "Đường Cầu Binh",
                "Đường Cống Bi",
                "Đường Cổng Sa Đông",
                "Đường Cổng Vĩnh",
                "Đại Lộ Thăng Long",
                "Đường Đường bê tông Cao Trung",
                "Đường Đê",
                "Đường đi Dương Liễu",
                "Đường Khu Cầu",
                "Đường Khu Thượng",
                "Đường KCN An Khánh",
                "Đường Khu 7",
                "Đường Kim Chung",
                "Lai Xá",
                "Đường Láng Hòa Lạc",
                "Đường Lê Trọng Tấn",
                "Đường Mả Gạo",
                "Đường Minh Khai- Đức Thượng",
                "Phố Nấm",
                "QL 32",
                "Đường Quốc lộ 32",
                "Đường Quyết Tiến",
                "Đường Sơn Đồng",
                "Đường Thượng Thụy",
                "Đường Trãi",
                "Đường Yên Sở",
                "Đường Yên Sở-Sơn Đồng"
            ]
        },
        {
            "date": "2024-04-27 00:07:47",
            "name": "Ba Đình",
            "wards": [
                "An Dương",
                "Ba Đình",
                "Cách Bi",
                "Cát Linh",
                "Cống Vị",
                "Cửa Đông",
                "Điện Biên",
                "Đội Cấn",
                "Đống Đa",
                "Giang Minh",
                "Giảng Võ",
                "Kim Mã",
                "Láng Hạ",
                "Láng Thượng",
                "Liễu Giai",
                "Nam Đồng",
                "Ngọc Hà",
                "Ngọc Khánh",
                "Nguyễn Trung Trực",
                "Phúc Xá",
                "Phường Cấn",
                "Phường Hàng Mã",
                "phường Ô Chợ Dừa",
                "Quán Thánh",
                "Sơn Tây",
                "Thái Hà",
                "Thành Công",
                "Trúc Bạch",
                "Vĩnh Phúc",
                "Yên Phụ"
            ],
            "streets": [
                "Văn An",
                "Chùa Láng",
                "Phố Chùa Một Cột",
                "Đường Cơ Xá",
                "Phố Cửa Bắc",
                "Phố Cửa Đông",
                "Phố Đặng Dung",
                "Phố Đặng Tất",
                "Đường Đào Tấn",
                "Đê La Thành",
                "Đường Điện Biên Phủ",
                "Đường Độc Lập",
                "Phố Đốc Ngữ",
                "Phố Đội Cấn",
                "Đường Đội Nhân",
                "Đường 9",
                "Đường Bưởi",
                "Đường Cửa Bắc",
                "Đường Hoàng Diệu",
                "Đường Kim Mã",
                "Đường Láng Hạ",
                "Đường Liễu Giai",
                "Đường Lĩnh Lang",
                "Đường Nguyễn Thái Học",
                "Đường Quán Thánh",
                "Đường Trần Huy Liệu",
                "Đường Trúc Bạch",
                "Phố Giang Văn Minh",
                "Phố Giảng Võ",
                "Phố Hàng Bún",
                "Phố Hàng Than",
                "Đường Hoàng Diệu",
                "Đường Hoàng Hoa Thám",
                "Đường Hoàng Văn Thụ",
                "Phố Hòe Nhai",
                "Đường Hồng Hà",
                "Phố Hồng Phúc",
                "Đường Hùng Vương",
                "Đường Huỳnh Thúc Kháng",
                "Khu tập thể A5",
                "Đường Khu tập thể Thành Công",
                "Đường Khúc Hạo",
                "Phố Kim Mã",
                "Phố Kim Mã Thượng",
                "Đường La Thành",
                "Phố Lạc Chính",
                "Đường Lạc Long Quân",
                "Phố Láng Hạ",
                "Đường Lê Duẩn",
                "Lê Duẩn",
                "Phố Lê Hồng Phong",
                "Phố Lê Trực",
                "Phố Liễu Giai",
                "Phố Linh Lang",
                "Lý Nam Đế",
                "Phố Mạc Đĩnh Chi",
                "Phố Mai Anh Tuấn",
                "Phố Nam Cao",
                "Phố Nam Tràng",
                "Ngách 10/75 Nguyễn Công Hoan",
                "Ngách 173/134 Hoàng Hoa Thám",
                "Phố Nghĩa Dũng",
                "Đường Ngõ 16, Huỳnh Thúc Kháng",
                "Phố Ngọc Hà",
                "Phố Ngọc Khánh",
                "Phố Ngũ Xã",
                "Phố Nguyễn Biểu",
                "Phố Nguyễn Cảnh Chân",
                "Đường Nguyễn Chí Thanh",
                "Phố Nguyễn Công Hoan",
                "Phố Nguyên Hồng",
                "Phố Nguyễn Khắc Hiếu",
                "Phố Nguyễn Khắc Nhu",
                "Đường Nguyễn Thái Học",
                "Phố Nguyễn Thái Học",
                "Phố Nguyễn Thiệp",
                "Đường Nguyễn Tri Phương",
                "Đường Nguyễn Trung Trực",
                "Phố Nguyễn Trường Tộ",
                "Phố Nguyễn Văn Ngọc",
                "Đường Núi Đôi",
                "Phố Núi Trúc",
                "Phố Ông Ích Khiêm",
                "Phố Phạm Hồng Thái",
                "Phố Phạm Huy Thông",
                "Phố Phan Đình Phùng",
                "Phố Phan Huy Ích",
                "Phố Phan Kế Bính",
                "Phố Phó Đức Chính",
                "Phố Ngọc Hà",
                "Đường Phúc Diễn",
                "Phố Phúc Xá",
                "Phường Quán Thánh",
                "Phố Quần Ngựa",
                "Phố Quán Thánh",
                "Phố Sơn Tây",
                "Phố Tân Ấp",
                "Thái Hà",
                "Đường Thanh Báo",
                "Phố Thanh Bảo",
                "Phố Thành Công",
                "Phố Tôn Thất Đảm",
                "Phố Tôn Thất Thiệp",
                "Phố Trần Huy Liệu",
                "Phố Trần Phú",
                "Phố Trần Tế Xương",
                "Phố Trấn Vũ",
                "Phố Trịnh Hoài Đức",
                "Phố Trúc Bạch",
                "Từ Phong",
                "Phố Vạn Bảo",
                "Phố Văn Cao",
                "Phố Vạn Phúc",
                "Đường Vĩnh Phúc",
                "Phố Yên Ninh",
                "Đường Yên Phụ",
                "Phố Yên Thế"
            ]
        },
        {
            "date": "2024-04-27 00:07:48",
            "name": "Thạch Thất",
            "wards": [],
            "streets": [
                "Phố Bãi Cháy",
                "Đường Bãi Dài",
                "Đường Bình Sơn",
                "Đường Chàng Sơn",
                "Phố Chợ Bò",
                "Đường Cống Đặng",
                "Đường Cổng Đông",
                "Phố Cổng Hàng",
                "Đường Đình Trong",
                "Đường Đồng Cao",
                "Đường Đồng Dâu",
                "Đường 420",
                "Đường 8-3",
                "Đường Chăn Nuôi",
                "Đường Ngã 3",
                "Đường Phùng Xá",
                "Đường Giếng Bìm",
                "Đường Gò Chè",
                "Đường Gò Chói",
                "Phố Hoa Sữa",
                "Đường Miễu",
                "Đường Nhòn",
                "Phùng Xá",
                "Đường Quê Vải",
                "Đường Quốc lộ 21",
                "Đường Suối Ngọc",
                "Đường Thị trấn Liên Quan",
                "Thôn Dị",
                "Đường Thúy Lai",
                "Tỉnh lộ 80",
                "Đường Tỉnh lộ 84",
                "Đường Trại Mới",
                "Đường Xã Yên Bình",
                "Đường Xanh Villas Khu đô thị Xanh Villas",
                "Đường Xóm Chùa",
                "Đường Yên Bình"
            ]
        },
        {
            "date": "2024-04-27 00:07:48",
            "name": "Nam Từ Liêm",
            "wards": [
                "Cầu Diễn",
                "Đại Mỗ",
                "Mễ Trì",
                "Mỹ Đình",
                "Mỹ Đình 2",
                "Phú Đô",
                "Phương Canh",
                "Tây Mỗ",
                "Trung Văn",
                "Xuân Phương"
            ],
            "streets": [
                "Đường AR 6",
                "Bùi Xuân Phái",
                "Đường Cao Xuân Huy",
                "Đường Cầu Diễn",
                "Đường Cầu Đôi",
                "Cầu Triền",
                "Châu Văn Liêm",
                "Đường Cương Kiên",
                "Đường Đại Lộ Thăng Long",
                "Đình Thôn",
                "Đường Đỗ Đình Thiện",
                "Đường Đỗ Đức Dục",
                "Đường Đồng Bát",
                "Đường DreamTown",
                "Đường 2",
                "Đường Đường 70",
                "Đường CD 2 KĐT Nam Trung Yên",
                "Đường Đường Hồ Mễ Trì",
                "Đường Đường K1",
                "Đường Đường K1B",
                "Đường Đường K2",
                "Đường Đường K3",
                "Đường K4",
                "Đường SP 2 KĐT Nam Trung Yên",
                "Đường Trung Văn",
                "Đường Vạn Phúc",
                "Giao Quang",
                "Đường Hàm Nghi",
                "Đường Hàm Nghi",
                "Đường Hồ Mễ Trì",
                "Phố Hỏa Lò",
                "Đường Hoài Thanh",
                "Đường Hoàng Công Chất",
                "Phố Hòe Thị",
                "Hữu Hưng",
                "Đường KĐT Mễ Trì Thượng, Mễ Trì",
                "Khu B -Tòa Nhà An Sinh",
                "Đường Khu đô thị Mễ Trì Hạ",
                "Khu liên hợp thể thao quốc gia",
                "Khu TT4",
                "Đường Láng - Hòa Lạc",
                "Làng Phú Đô",
                "Đường Lê Đức Thọ",
                "Lê Quang Đạo",
                "Đường Liên Cơ",
                "Đường LS 5",
                "Đường Lưu Hữu Phước",
                "Đường Mễ Trì",
                "Đường Miêu Nha",
                "Đường Mỹ Đình",
                "Đường Ngân Hàng",
                "Ngọc Đại",
                "Đường Ngọc Trục",
                "Đường Nguyễn Cơ Thạch",
                "Đường Nguyễn Đổng Chi",
                "Đường Nguyễn Hoàng",
                "Đường Nguyễn Trãi",
                "Đường Nhuệ Giang",
                "Đường Phạm Hùng",
                "Đường Phố Cầu Cốc",
                "Đường Phố Thiên Hiền",
                "Đường Phú Diễn",
                "Đường Phú Đô",
                "Đường Phùng Khoang",
                "Đường Phương Canh",
                "Đường Quang Tiến",
                "Đường Quốc lộ 32",
                "Đường Tân Mỹ",
                "Đường Tây Mỗ",
                "Đường Thị Cẩn",
                "Đường Thiên Hiền",
                "Thôn An Thái",
                "đường Tỉnh lộ 70",
                "Đường Tỉnh lộ 72",
                "Đường Tố Hữu",
                "Đường Tôn Thất Thuyết",
                "Đường Trần Hữu Dực",
                "Đường Trần Văn Cẩn",
                "Đường Trần Văn Lai",
                "Đường Trung Văn",
                "Đường Vũ Đình Tụng",
                "Đường Vũ Quỳnh",
                "Đường Vườn Cam",
                "Xuân Phương",
                "Đường Yên Hòa Đại Mỗ"
            ]
        },
        {
            "date": "2024-04-27 00:07:49",
            "name": "Ba Vì",
            "wards": [
                "Cam Thượng",
                "Châu Sơn",
                "Chu Minh",
                "Đông Quang",
                "Khai Quang",
                "Minh Châu",
                "Phố Tân Phú Mỹ",
                "Phú Sơn",
                "Tản Lĩnh",
                "Tân Phong",
                "Thị trấn Tây Đằng",
                "Tòng Bạt",
                "Vân Hòa",
                "Vật Lại"
            ],
            "streets": [
                "Đường Cầu Và, tản lĩnh",
                "Cầu Vật Phụ",
                "Đường 93",
                "Mê Linh",
                "Đường Quốc lộ 32",
                "Đường Vật Lại",
            ]
        },
        {
            "date": "2024-04-27 00:07:49",
            "name": "Thanh Trì",
            "wards": [
                "Phường Hữu Hòa",
                "Thanh Liệt",
                "Thị trấn Văn Điển",
                "Xã Đại Áng",
                "Xã Đông Mỹ",
                "Xã Duyên Hà",
                "Xã Liên Ninh",
                "Xã Ngọc Hồi",
                "Xã Ngũ Hiệp",
                "Xã Tả Thanh Oai",
                "Xã Tam Hiệp",
                "Xã Tân Triều",
                "Xã Thanh Liệt",
                "Xã Tứ Hiệp",
                "Xã Vạn Phúc",
                "Xã Vĩnh Quỳnh",
                "Xã Yên Mỹ"
            ],
            "streets": [
                "Đường Cao tốc Pháp Vân",
                "Cầu chui",
                "Đường Cầu Tó",
                "Đường Cầu Tó, Thanh Liệt",
                "Đường Chiến Thắng",
                "Đường Đường 70",
                "Đường Hữu Lê",
                "Đường Ích Vinh",
                "Đường KĐT Đại Thanh",
                "Đường KĐT Yên Xá",
                "Kho 6",
                "Đường Khu chung cư Bộ Tư Lệnh Đặc Công",
                "Km 1 Phan Trọng Tuệ",
                "Đường Lạc Thị",
                "Lưu Phái",
                "Đường Ngõ 130, Đường Tựu Liệt",
                "Ngọc Hồi",
                "Đường Ngọc Hồi",
                "Đường Ngũ Hiệp",
                "Đường Phan Trọng Tuệ",
                "Đường Quốc lộ 1",
                "Đường Quốc lộ 1A",
                "Đường Quỳnh Đô",
                "Tả Thanh Oai",
                "Đường Tân Triều",
                "Đường Thanh Liệt",
                "Thôn Huỳnh Cung",
                "Đường Thôn Phương Nhị",
                "Thôn Yên Ngưu",
                "Đường Tỉnh lộ 70",
                "Đường Tranh Khúc",
                "Đường Triều Khúc",
                "Đường Tứ Hiệp",
                "Đường Tựu Liệt",
                "Đường Vĩnh Ninh",
                "Đường Vĩnh Thịnh"
            ]
        },
        {
            "date": "2024-04-27 00:07:49",
            "name": "Quốc Oai",
            "wards": [
                "Đồng Quang",
                "Đông Yên",
                "Hòa Thạch",
                "Phú Cát",
                "Quang Trung",
                "Thạch Thán",
                "Thị trấn Quốc Oai"
            ],
            "streets": [
                "Đặng Tiến Đông",
                "Đông Hạ",
                "Phú Cát",
                "Đường Quốc Oai",
                "Đường Tỉnh lộ 419",
                "Trại Vàng"
            ]
        },
        {
            "date": "2024-04-27 00:07:50",
            "name": "Tây Hồ",
            "wards": [
                "Bưởi",
                "Nhật Tân",
                "Phú Thượng",
                "Phúc Xá",
                "Phường Trúc Bạch",
                "Quảng An",
                "Thụy Khuê",
                "Từ Liêm",
                "Tứ Liên",
                "Xuân La",
                "Yên Phụ"
            ],
            "streets": [
                "Lạc Long Quân",
                "614 Lạc Long Quân",
                "Đường An Dương",
                "Đường An Dương Vương",
                "Đường An Thành 2",
                "Đường Anh Thành 1",
                "Đường Âu Cơ",
                "Đường Đặng Thai Mai",
                "Phố Dốc Tam Đa",
                "Đường Academy Khu đô thị Ciputra",
                "Đường Âu Cơ",
                "Đường Promenade Khu đô thị Ciputra",
                "Đường Đường SIS Khu đô thị Ciputra",
                "Đường UNIS Khu đô thị Ciputra",
                "Đường Yên Hoa",
                "Đường Hoàng Hoa Thám",
                "Đường Hoàng Hoa Thám",
                "Đường Hồng Hà",
                "Đường Lạc Long Quân",
                "Đường Lake Road Khu đô thị Ciputra",
                "Đường Mai Xuân Thưởng",
                "Đường Nghi Tàm",
                "Đường Nguyễn Hoàng Tôn",
                "Đường Nhật Chiêu",
                "Đường Nước Phần Lan",
                "Phố Atlas Khu đô thị Ciputra",
                "Phố Main Khu đô thị Ciputra",
                "Phố Park Khu đô thị Ciputra",
                "Phố Pegasus Khu đô thị Ciputra",
                "Đường Phú Gia",
                "Đường Phú Xá",
                "Đường Quảng Bá",
                "Đường Tây Hồ",
                "Đường Thanh Niên",
                "Thượng Thụy",
                "Thụy Khê",
                "Đường Thụy Khuê",
                "Đường Tô Ngọc Vân",
                "Đường Trích Sài",
                "Đường Từ Hoa Công Chúa",
                "Đường Vệ Hồ",
                "Đường Ven Hồ",
                "Đường Ven Hồ Tây",
                "Đường Ven Hồ Thụy Khuê",
                "Đường Võ Chí Công",
                "Phố Võng Thị",
                "Đường Xuân Diệu",
                "Đường Xuân La",
                "Yên Hoa",
                "Đường Yên Phụ"
            ]
        },
        {
            "date": "2024-04-27 00:07:50",
            "name": "Thanh Xuân",
            "wards": [
                "Định Công",
                "Đồng Tâm",
                "Giáp Bát",
                "Hạ Đình",
                "Hà Đông",
                "Hoàng Liệt",
                "Khương Đình",
                "Khương Mai",
                "Khương Thượng",
                "Khương Trung",
                "Khương Trung Mới",
                "Kim Giang",
                "Ngã Tư Sở",
                "Nguyễn Trãi",
                "Nhân Chính",
                "Phường Đại Kim",
                "Phương Liệt",
                "Quan Nhân",
                "Tân Triều",
                "Thanh Trì",
                "Thanh Xuân",
                "Thanh Xuân Bắc",
                "Thanh Xuân Nam",
                "Thanh Xuân Trung",
                "Thịnh Liệt",
                "Thượng Đình",
                "Trung Hòa",
                "Trung Hòa Nhân Chính",
                "Trung Văn",
                "Văn Quán"
            ],
            "streets": [
                "17T6 Khu Đô Thị",
                "18T Phố Nhân Hòa",
                "98 Ngõ 64",
                "Bắc Linh Đàm",
                "Đường Bồ Đề",
                "Đường Bùi Xương Trạch",
                "Phố Chính Kinh",
                "Phố Cù Chính Lan",
                "Phố Cự Lộc",
                "Đường Định Công",
                "Đường Hạ Đình",
                "Đường Khương Đình",
                "Đường Khương Hạ",
                "Đường Khương Trung mới",
                "Đường Lương Thế Vinh",
                "Đường Nguyễn Huy Tưởng",
                "Đường Nguyễn Trãi",
                "Đường Triều Khúc",
                "Đường Trường Chinh",
                "Đường vào Đại Học Hà Nội",
                "Đường Giải Phóng",
                "Đường Giáp Nhất",
                "Phố Hạ Đình",
                "Đường Hoàng Đạo Thành",
                "Đường Hoàng Đạo Thúy",
                "Phố Hoàng Minh Giám",
                "Phố Hoàng Ngân",
                "Phố Hoàng Văn Thái",
                "Đường Hồng Liên",
                "Khu tập thể Cơ khí Hà Nội",
                "Khu tập thể Thanh Xuân Bắc",
                "Khu tập thể Thanh Xuân Nam",
                "Đường Khuất Duy Tiến",
                "Đường Khương Đình",
                "Đường Khương Đình Mới",
                "Phố Khương Hạ",
                "Khương Hạ Mới",
                "Phố Khương Trung",
                "Đường Khương Trung mới",
                "Đường Lê Văn Lương",
                "Phố Lê Văn Thiêm",
                "LK làng Việt Kiều Châu Âu",
                "Đường Lương Thế Vinh",
                "Đường Ngõ 211 Khương Trung",
                "Phố Ngụy Như Kon Tum",
                "Đường Ngụy Như Kontum, Nhân Chính",
                "Đường Nguyễn Đức Quý",
                "Phố Nguyễn Huy Tưởng",
                "Phố Nguyễn Ngọc Nại",
                "Đường Nguyễn Ngọc Vũ",
                "Phố Nguyễn Quý Đức",
                "Phố Nguyễn Thị Định",
                "Nguyễn Thị Thập",
                "Đường Nguyễn Tuân",
                "Phố Nguyễn Văn Trỗi",
                "Phố Nguyễn Viết Xuân",
                "Đường Nguyễn Xiển",
                "Phố Nhân Hòa",
                "Phố Phan Đình Giót",
                "Phố Lê Trọng Tấn",
                "Phùng Khoang",
                "Phố Phương Liệt",
                "Phố Quan Nhân",
                "Sông Lừ",
                "Tố Hữu",
                "Phố Tô Vĩnh Diện",
                "Đường Trần Điền",
                "Đường Trường Chinh",
                "Phố Vũ Hữu",
                "Đường Vũ Tông Phan",
                "Đường Vũ Trọng Phụng",
                "Phố Vương Thừa Vũ"
            ]
        }
    ]
}
